#!/usr/bin/python
# encoding: utf-8
from setuptools import setup, find_packages

setup(
    name="sbiqer",
    version="0.1",
    license="MIT Licence",

    url="https://github.com/srx-2000/sbiqer",
    author="beier",
    author_email="1601684622@qq.com",

    packages=find_packages(),
    include_package_data=True,
    platforms="any",
    install_requires=[]
)